==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetInteractionTranscription.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTE SP RETORN LAS TRANSCRIPCIONES DE UNA INTERACCION SEGUN SU VCC, INTERACTIONTYPE(CHANNEL), INTERACTIONID
CREATE PROCEDURE [dbo].[GetInteractionTranscription] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = null,
	@ProcessId VARCHAR(50) = NULL,
	@InteractionType VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SI PROCESSID IS NULL RETORNA TODAS LAS TRANSCRIPCIONES DEL ID
	-- SI PROCESSID IS NOT NULL RETORNA TOADAS LAS TRANSCRIPCIONES DE ID RELACIONADAS CON EL PROCESSASYNCINTERACTION

	-- AGREGAMOS LA BUSQUEDA PARA CANALES DE TEXTO
	IF @InteractionType <> 'CALL'
	BEGIN
		-- PARA EL CASO QUE PLAN DE EVALUACION ID ES NULL
		IF @EvaluationPlanId IS NULL
		BEGIN
			SELECT DISTINCT AI.[VCC]					'vcc',
							AI.[Campaign]				'campaign',
							AI.[Channel]				'interactionType',
							AI.[ID]						'interactionId',
							AI.[Folder]					'folder',
							AI.[FileName]				'jsonFileName',
							AI.[ViewFileName]			'viewFileName',
							P.[Name]					'processId',
							AI.[TotalMessages]			'totalMessages'
				FROM [dbo].[AsyncInteraction] AI (NOLOCK)
				LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
					ON PAI.[VCC] = AI.[VCC]
						AND PAI.[Campaign] = AI.[Campaign]
						AND PAI.[InteractionType] = AI.[Channel]
						AND PAI.[FormattedEndDate] = AI.[Folder]
						AND PAI.[InteractionId] = AI.[ID]
						AND PAI.[ProcessId] = @ProcessId
				LEFT JOIN [dbo].[Process] P (NOLOCK)
					ON P.[VCC] = AI.[VCC]
						AND P.[Name] = PAI.[ProcessId]
				WHERE AI.[VCC] = @VCC
					AND AI.[Channel] = @InteractionType
					AND AI.[ID] = @InteractionId
					AND AI.[IsTranscribed] = 1
					AND (
						(@ProcessId IS NOT NULL AND PAI.[ProcessId] IS NOT NULL)
						OR
						(@ProcessId IS NULL AND PAI.[ProcessId] IS NULL)	
					)
				ORDER BY AI.[Folder] ASC

		END
		ELSE
		BEGIN
			SELECT IEP.[Instance]						'vcc',
					IEP.[IdCampaign]					'campaign',
					IEP.[InteractionType]				'interactionType',
					IEP.[IdInteraction]					'interactionId',
					IEP.[FormattedEndDate]				'folder',
					NULL								'jsonFileName',
					NULL								'viewFileName',
					NULL								'processId',
					IEP.[InteractionMessages]			'totalMessages'
				FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				WHERE IEP.[Instance] = @VCC
					AND IEP.[IdEvaluationPlan] = @EvaluationPlanId
					AND IEP.[InteractionType] = @InteractionType
					AND IEP.[IdInteraction] = @InteractionId 
		END
	END
	ELSE 
	BEGIN
		-- PARTE OPCIONAL PARA INTERACCIONES CALL, AUN NO IMPLEMENTADO
		DECLARE @ID VARCHAR(50) = ''
		IF EXISTS (
			SELECT 1 
				FROM [dbo].[Audio] A (NOLOCK)
				WHERE A.[VCC] = 'occ_test'--@VCC 
					AND (
						(CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
						OR
						(A.[ID] = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
					)
		) 
		BEGIN
			SET @ID = (
						SELECT TOP 1 A.[ID]
							FROM [dbo].[Audio] A (NOLOCK)
								WHERE A.[VCC] = 'occ_test'--@VCC 
									AND (
										(CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
										OR
										(A.[ID] = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
									)
						)

			SELECT *
				FROM [dbo].[Audio] A (NOLOCK)
				WHERE A.[VCC] = 'occ_test'--@VCC 
					AND A.[ID] = @ID
		END

		SELECT 'SOON...'

	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetInteractionTranscription.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTE SP RETORN LAS TRANSCRIPCIONES DE UNA INTERACCION SEGUN SU VCC, INTERACTIONTYPE(CHANNEL), INTERACTIONID
CREATE PROCEDURE [dbo].[GetInteractionTranscription] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = null,
	@ProcessId VARCHAR(50) = NULL,
	@InteractionType VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SI PROCESSID IS NULL RETORNA TODAS LAS TRANSCRIPCIONES DEL ID
	-- SI PROCESSID IS NOT NULL RETORNA TOADAS LAS TRANSCRIPCIONES DE ID RELACIONADAS CON EL PROCESSASYNCINTERACTION

	-- AGREGAMOS LA BUSQUEDA PARA CANALES DE TEXTO
	IF @InteractionType <> 'CALL'
	BEGIN
		-- PARA EL CASO QUE PLAN DE EVALUACION ID ES NULL
		IF @EvaluationPlanId IS NULL
		BEGIN 
			SELECT DISTINCT AI.[VCC]									'vcc',
							AI.[Campaign]								'campaign',
							AI.[Channel]								'interactionType',
							AI.[ID]										'id',
							AI.[ID]										'interactionId',
							AI.[Folder]									'folder',
							AI.[FileName]								'jsonFileName',
							AI.[ViewFileName]							'viewFileName',
							P.[Name]									'processId',
							AI.[TotalMessages]							'totalMessages',
							AI.[NeedI6Update]							'needI6Update'
				FROM [dbo].[AsyncInteraction] AI (NOLOCK)
				LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
					ON PAI.[VCC] = AI.[VCC]
						AND PAI.[Campaign] = AI.[Campaign]
						AND PAI.[InteractionType] = AI.[Channel]
						AND PAI.[FormattedEndDate] = AI.[Folder]
						AND PAI.[InteractionId] = AI.[ID]
						AND PAI.[ProcessId] = @ProcessId
				LEFT JOIN [dbo].[Process] P (NOLOCK)
					ON P.[VCC] = AI.[VCC]
						AND P.[Name] = PAI.[ProcessId]
				WHERE AI.[VCC] = @VCC
					AND AI.[Channel] = @InteractionType
					AND AI.[ID] = @InteractionId
					AND AI.[IsTranscribed] = 1
					AND (
						(@ProcessId IS NOT NULL AND PAI.[ProcessId] IS NOT NULL)
						OR
						(@ProcessId IS NULL AND PAI.[ProcessId] IS NULL)	
					)
				ORDER BY AI.[Folder] ASC

		END
		ELSE
		BEGIN
			SELECT IEP.[Instance]										'vcc',
					IEP.[IdCampaign]									'campaign',
					IEP.[InteractionType]								'interactionType',
					IEP.[IdInteraction]									'id',
					IEP.[IdInteraction]									'interactionId',
					IEP.[FormattedEndDate]								'folder',
					AI.[FileName]										'jsonFileName',
					AI.[ViewFileName]									'viewFileName',
					EP.[ProcessId]										'processId',
					IEP.[InteractionMessages]							'totalMessages',
					IEP.[NeedI6Update]									'needI6Update'
				FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK) 
					ON EP.[Instance] = IEP.[Instance]
						AND EP.[ID] = IEP.[IdEvaluationPlan]
				LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
					ON PAI.[VCC] = IEP.[Instance]
						AND PAI.[Campaign] = IEP.[IdCampaign]
						AND PAI.[InteractionType] = IEP.[InteractionType]
						AND PAI.[FormattedEndDate] = IEP.[FormattedEndDate]
						AND PAI.[InteractionId] = IEP.[IdInteraction]
						AND PAI.[ProcessId] = EP.[ProcessId]
				LEFT JOIN [dbo].[Process] P (NOLOCK)
					ON P.[VCC] = IEP.[Instance]
						AND P.[Name] = EP.[ProcessId]
				LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
					ON AI.[VCC] = IEP.[Instance]
						AND AI.[Campaign] = PAI.[Campaign]
						AND AI.[Channel] = PAI.[InteractionType] 
						AND AI.[Folder] = PAI.[FormattedEndDate]
						AND AI.[ID] = PAI.[InteractionId]
				WHERE IEP.[Instance] = @VCC
					AND IEP.[IdEvaluationPlan] = @EvaluationPlanId
					AND IEP.[InteractionType] = @InteractionType
					AND IEP.[IdInteraction] = @InteractionId 
		END
	END
	ELSE 
	BEGIN
		-- PARTE OPCIONAL PARA INTERACCIONES CALL, AUN NO IMPLEMENTADO
		DECLARE @ID VARCHAR(50) = ''
		IF EXISTS (
			SELECT 1 
				FROM [dbo].[Audio] A (NOLOCK)
				WHERE A.[VCC] = 'occ_test'--@VCC 
					AND (
						(CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
						OR
						(A.[ID] = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
					)
		) 
		BEGIN
			SET @ID = (
						SELECT TOP 1 A.[ID]
							FROM [dbo].[Audio] A (NOLOCK)
								WHERE A.[VCC] = 'occ_test'--@VCC 
									AND (
										(CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
										OR
										(A.[ID] = '{23c5b766-4d29-11ea-b486-a4420ef40d06}_0_1')
									)
						)

			SELECT *
				FROM [dbo].[Audio] A (NOLOCK)
				WHERE A.[VCC] = 'occ_test'--@VCC 
					AND A.[ID] = @ID
		END

		SELECT 'SOON...'

	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
